==> haskell-http-client-restricted-0.1.0-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-20YPhpYaAWb4Ti5R1zMLpP
key:                  http-client-restricted-0.1.0-20YPhpYaAWb4Ti5R1zMLpP
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  9a109b456ba9fe4694b78361ba85461a
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-20YPhpYaAWb4Ti5R1zMLpP
depends:
    base-4.18.2.1 crypton-connection-0.4.5-IRXuN8rt5iD9iK3x9Ixu0j
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    http-client-0.7.19-B5USSZypF8s1UPWufciwbp
    http-client-tls-0.3.6.4-EXJYBmDnK2u6DuzznW70M4
    network-3.1.4.0-DqImTC0JtBs7wAjAQOfbw6
    network-bsd-2.8.1.0-2FRtrywvz2KB3NVtr6LNTj
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-restricted-0.1.0-190-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-F5oMad5FedJGZX5IyPGwlc
key:                  http-client-restricted-0.1.0-F5oMad5FedJGZX5IyPGwlc
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  c247fd217cdea3012414027e84e666f5
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-F5oMad5FedJGZX5IyPGwlc
depends:
    base-4.18.2.1 crypton-connection-0.4.5-IRXuN8rt5iD9iK3x9Ixu0j
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    http-client-0.7.19-KAsH6CgaLEPAFMwCgIBejb
    http-client-tls-0.3.6.4-JIwEy8eUUufD8fETx9XfAs
    network-3.1.4.0-DqImTC0JtBs7wAjAQOfbw6
    network-bsd-2.8.1.0-2FRtrywvz2KB3NVtr6LNTj
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
